@@ -1,6 +1,6 @@
 package SPVM::MIME::Base64;
 
-our $VERSION = "1.001";
+our $VERSION = "1.002";
 
 1;
 
@@ -23,7 +23,7 @@ The MIME::Base64 class of L<SPVM> has methods for L<Base64|https://en.wikipedia.
 
 =head2 encode_base64
 
-  static method encode_base64 : string ($string : string, $eol = undef : string);
+C<static method encode_base64 : string ($string : string, $eol : string = undef);>
 
 Encodes the string $string to a Base64 string, and returns it.
 
@@ -37,11 +37,11 @@ to be broken into lines.
 
 Exceptions:
 
-The $string must be defined. Otherwise an exception is thrown.
+$string must be defined. Otherwise an exception is thrown.
 
 =head2 decode_base64
 
-  static method decode_base64 : string ($string : string);
+C<static method decode_base64 : string ($string : string);>
 
 Decodes a Base64 string $string to a string, and returns it.
 
@@ -51,11 +51,11 @@ are never decoded.
 
 Exceptions:
 
-The $string must be defined. Otherwise an exception is thrown.
+$string must be defined. Otherwise an exception is thrown.
 
 =head2 encoded_base64_length
 
-  static method encoded_base64_length : int ($string : string, $eol = undef : string);
+C<static method encoded_base64_length : int ($string : string, $eol : string = undef);>
 
 Returns the length that the encoded string would have without actually
 encoding it.
@@ -65,11 +65,11 @@ but should be more efficient.
 
 Exceptions:
 
-The $string must be defined. Otherwise an exception is thrown.
+$string must be defined. Otherwise an exception is thrown.
 
 =head2 decoded_base64_length
 
-  static method decoded_base64_length : int ($string : string);
+C<static method decoded_base64_length : int ($string : string);>
 
 Returns the length that the decoded string would have without actually
 decoding it.
@@ -79,7 +79,7 @@ but should be more efficient.
 
 Exceptions:
 
-The $string must be defined. Otherwise an exception is thrown.
+$string must be defined. Otherwise an exception is thrown.
 
 =head1 Other Modules in This Distribution
 
